@@ -26,7 +26,7 @@ import jsii
 import jsii.compat
 import publication
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/cdk-assets-schema", "1.28.0", __name__, "cdk-assets-schema@1.28.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/cdk-assets-schema", "1.30.0", __name__, "cdk-assets-schema@1.30.0.jsii.tgz")
 
 
 class AssetManifestSchema(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/cdk-assets-schema.AssetManifestSchema"):
@@ -162,21 +162,19 @@ class DockerImageAsset():
         return 'DockerImageAsset(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-@jsii.data_type(jsii_type="@aws-cdk/cdk-assets-schema.DockerImageDestination", jsii_struct_bases=[AwsDestination], name_mapping={'assume_role_arn': 'assumeRoleArn', 'assume_role_external_id': 'assumeRoleExternalId', 'region': 'region', 'image_tag': 'imageTag', 'image_uri': 'imageUri', 'repository_name': 'repositoryName'})
+@jsii.data_type(jsii_type="@aws-cdk/cdk-assets-schema.DockerImageDestination", jsii_struct_bases=[AwsDestination], name_mapping={'assume_role_arn': 'assumeRoleArn', 'assume_role_external_id': 'assumeRoleExternalId', 'region': 'region', 'image_tag': 'imageTag', 'repository_name': 'repositoryName'})
 class DockerImageDestination(AwsDestination):
-    def __init__(self, *, assume_role_arn: typing.Optional[str]=None, assume_role_external_id: typing.Optional[str]=None, region: typing.Optional[str]=None, image_tag: str, image_uri: str, repository_name: str):
+    def __init__(self, *, assume_role_arn: typing.Optional[str]=None, assume_role_external_id: typing.Optional[str]=None, region: typing.Optional[str]=None, image_tag: str, repository_name: str):
         """Where to publish docker images.
 
         :param assume_role_arn: The role that needs to be assumed while publishing this asset. Default: - No role will be assumed
         :param assume_role_external_id: The ExternalId that needs to be supplied while assuming this role. Default: - No ExternalId will be supplied
         :param region: The region where this asset will need to be published. Default: - Current region
         :param image_tag: Tag of the image to publish.
-        :param image_uri: Full Docker tag coordinates (registry and repository and tag). Example:: 1234.dkr.ecr.REGION.amazonaws.com/REPO:TAG
         :param repository_name: Name of the ECR repository to publish to.
         """
         self._values = {
             'image_tag': image_tag,
-            'image_uri': image_uri,
             'repository_name': repository_name,
         }
         if assume_role_arn is not None: self._values["assume_role_arn"] = assume_role_arn
@@ -215,16 +213,6 @@ class DockerImageDestination(AwsDestination):
         """Tag of the image to publish."""
         return self._values.get('image_tag')
 
-    @builtins.property
-    def image_uri(self) -> str:
-        """Full Docker tag coordinates (registry and repository and tag).
-
-        Example::
-
-           1234.dkr.ecr.REGION.amazonaws.com/REPO:TAG
-        """
-        return self._values.get('image_uri')
-
     @builtins.property
     def repository_name(self) -> str:
         """Name of the ECR repository to publish to."""
@@ -498,6 +486,30 @@ class ManifestFile():
         return 'ManifestFile(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-__all__ = ["AssetManifestSchema", "AwsDestination", "DockerImageAsset", "DockerImageDestination", "DockerImageSource", "FileAsset", "FileAssetPackaging", "FileDestination", "FileSource", "ManifestFile", "__jsii_assembly__"]
+class Placeholders(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/cdk-assets-schema.Placeholders"):
+    """Placeholders which can be used in the destinations."""
+    def __init__(self) -> None:
+        jsii.create(Placeholders, self, [])
+
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="CURRENT_ACCOUNT")
+    def CURRENT_ACCOUNT(cls) -> str:
+        """Insert this into the destination fields to be replaced with the current account."""
+        return jsii.sget(cls, "CURRENT_ACCOUNT")
+
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="CURRENT_PARTITION")
+    def CURRENT_PARTITION(cls) -> str:
+        """Insert this into the destination fields to be replaced with the current partition."""
+        return jsii.sget(cls, "CURRENT_PARTITION")
+
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="CURRENT_REGION")
+    def CURRENT_REGION(cls) -> str:
+        """Insert this into the destination fields to be replaced with the current region."""
+        return jsii.sget(cls, "CURRENT_REGION")
+
+
+__all__ = ["AssetManifestSchema", "AwsDestination", "DockerImageAsset", "DockerImageDestination", "DockerImageSource", "FileAsset", "FileAssetPackaging", "FileDestination", "FileSource", "ManifestFile", "Placeholders", "__jsii_assembly__"]
 
 publication.publish()
